@@ -9,6 +9,8 @@
 
 #include "incidenceeditor-ng.h"
 
+#include <memory>
+
 namespace Ui
 {
 class EventOrTodoDesktop;
@@ -37,9 +39,6 @@ public:
     void save(const KCalendarCore::Incidence::Ptr &incidence) override;
     Q_REQUIRED_RESULT bool isDirty() const override;
 
-    // For debugging purposes
-    Q_REQUIRED_RESULT bool richTextEnabled() const;
-
     void printDebugInfo() const override;
 
 private:
@@ -48,11 +47,10 @@ private:
     void setupToolBar();
 
 private:
-    Ui::EventOrTodoDesktop *mUi = nullptr;
+    Ui::EventOrTodoDesktop *const mUi;
     //@cond PRIVATE
     Q_DECLARE_PRIVATE(IncidenceDescription)
-    IncidenceDescriptionPrivate *const d;
+    std::unique_ptr<IncidenceDescriptionPrivate> const d;
     //@endcond
 };
 }
-
